summaryrefslogtreecommitdiff
path: root/src/lib/player.h
diff options
context:
space:
mode:
authorCarl Hetherington <cth@carlh.net>2022-01-21 21:53:54 +0100
committerCarl Hetherington <cth@carlh.net>2022-01-24 16:01:18 +0100
commit645936f18657c8d5c275cbf3443974784304d672 (patch)
treee9aab7d07abe66f3b49c12b9c8b33b7b87ef308d /src/lib/player.h
parent241f80c6265b3771a3f71f523a0f3400d852471d (diff)
Rename _last_video* to _next_video* as it seems to make more sense that way.
Diffstat (limited to 'src/lib/player.h')
-rw-r--r--src/lib/player.h11
1 files changed, 6 insertions, 5 deletions
diff --git a/src/lib/player.h b/src/lib/player.h
index b74aeeefd..bedf51d8e 100644
--- a/src/lib/player.h
+++ b/src/lib/player.h
@@ -196,11 +196,12 @@ private:
/** true if we should `play' (i.e output) referenced DCP data (e.g. for preview) */
bool _play_referenced = false;
- /** Time just after the last video frame we emitted, or the time of the last accurate seek */
- boost::optional<dcpomatic::DCPTime> _last_video_time;
- boost::optional<Eyes> _last_video_eyes;
- /** Time just after the last audio frame we emitted, or the time of the last accurate seek */
- boost::optional<dcpomatic::DCPTime> _last_audio_time;
+ /** Time of the next video that we will emit, or the time of the last accurate seek */
+ boost::optional<dcpomatic::DCPTime> _next_video_time;
+ /** Eyes of the next video that we will emit */
+ boost::optional<Eyes> _next_video_eyes;
+ /** Time of the next audio that we will emit, or the time of the last accurate seek */
+ boost::optional<dcpomatic::DCPTime> _next_audio_time;
boost::optional<int> _dcp_decode_reduction;